@@ -1,21 +1,18 @@
-# import atexit
+import atexit
 import os
 import sys
-import urllib.parse
 import uuid
 from types import FunctionType
 
-from werkzeug.exceptions import NotFound
+from werkzeug.exceptions import NotFound as SuperNotFound
 from werkzeug.routing import Map, Rule
 
-from .http import HttpRequest
+from restfx.globals import _app_ctx_stack
+from restfx.util import ContextStore, utils
+from .http import HttpRequest, NotFound, ServerError
 from .middleware import MiddlewareManager
 from .routes import Collector
 
-from restfx.globals import _app_ctx_stack
-
-from restfx.util import ContextStore
-
 
 class AppContext:
     def __init__(self, app):
@@ -115,9 +112,7 @@ class App:
 
         super(App, self).__init__()
 
-    # @atexit.register
-    # def dispose(self):
-    def __del__(self):
+    def dispose(self):
         self.config.middleware_manager.handle_shutdown()
 
         del self.config.middleware_manager
@@ -135,7 +130,6 @@ class App:
         :param start_response:
         :return:
         """
-        from .http import ServerError, NotFound as NewNotFound
 
         request = None
         response = None
@@ -154,16 +148,16 @@ class App:
             elif endpoint in self._custom_url_map:
                 response = self._custom_url_map[endpoint](request, **values)
             else:
-                response = NewNotFound()
+                response = NotFound()
         except Exception as e:
-            msg = '\n\t'.join(e.args)
+            msg = utils.get_exception_info(e)
             if request:
-                msg = 'Error occured during handle request %r:\n\t%s' % (request.path, msg)
+                msg = 'Error occurred during handling request %r:\n\t%s' % (request.path, msg)
 
-            self._logger.warning(msg)
+            self._logger.error(msg)
 
-            if isinstance(e, NotFound):
-                response = NewNotFound()
+            if isinstance(e, SuperNotFound):
+                response = NotFound()
             elif self.config.debug:
                 response = ServerError(msg.replace('<', '&lt;').replace('>', '&gt;'))
             else:
@@ -391,6 +385,15 @@ class App:
         获取指定的应用
         :param app_id:
         :return:
-        :rtype: AppContext
+        :rtype: App
         """
         return cls._APPS.get(app_id)
+
+
+@atexit.register
+def _destroy_apps():
+    # Parse the ids into list to avoid the error "RuntimeError: dictionary changed size during iteration"
+    app_ids = list(App._APPS.keys())
+    for app_id in app_ids:
+        app = App.get(app_id)
+        app.dispose()
