@@ -1,15 +1,15 @@
 import json
 from collections import OrderedDict
 from enum import Enum
-from functools import wraps, partial
+from functools import partial, wraps
 from typing import Tuple, Union
 
 from werkzeug.datastructures import MultiDict
 
+from .parameter_interface import IParam
 from .validator import Validator
 from ..config import AppConfig
-from ..http import HttpRequest, ServerError
-from ..http import HttpResponse, BadRequest, JsonResponse
+from ..http import BadRequest, HttpRequest, HttpResponse, JsonResponse, ServerError
 from ..routes.meta import RouteMeta
 from ..session import HttpSession
 from ..util import Logger
@@ -159,9 +159,11 @@ def _invoke_with_route(request: HttpRequest, meta: RouteMeta, config: AppConfig,
             result = func(**actual_args)
     except Exception as e:
         message = get_func_info(func)
-        Logger.get(config.app_id).error(message, e, False)
+        Logger.get(config.app_id).error(message, e)
+        if config.debug:
+            raise e
         from restfx.util import utils
-        return handle_response(ServerError(utils.get_exception_info(message, e)))
+        return handle_response(ServerError(message))
 
     return handle_response(wrap_response(result))
 
@@ -227,16 +229,11 @@ def _get_value(data: MultiDict, name: str, arg_spec: ArgumentSpecification):
         return result
 
     if is_arr:
+        # 请求参数本就为数组: param[]
         # 返回为 tuple 类型
-        return result, tuple(value)
+        return use_default, tuple(value)
 
-    # 校验值的类型 (list, tuple) 或者未指定类型时，允许其值为数组
-    if (not arg_spec.has_annotation and len(value) > 1) or arg_spec.annotation is tuple:
-        # 未指定类型时，使用 tuple 而不是 list
-        return tuple(result)
-    if arg_spec.annotation is list:
-        return result
-    # 其它类型时，取值列表中的最后一个值
+    # 当请求的不是数组时，使用最后一个值
     return use_default, value[-1]
 
 
@@ -269,6 +266,11 @@ def _get_input_value(arg_spec, arg_name, arg_value, config):
         return arg_value
 
     # 类型不一致，尝试转换类型
+    if arg_spec.annotation is tuple and isinstance(arg_value, list):
+        return tuple(arg_value)
+
+    if arg_spec.annotation is list and isinstance(arg_value, tuple):
+        return list(arg_value)
 
     # 当声明的参数类型是布尔类型时，收到的值可能是一个字符串（其值为 true 、 false）
     if arg_spec.annotation is bool and isinstance(arg_value, str):
@@ -294,6 +296,11 @@ def _get_input_value(arg_spec, arg_name, arg_value, config):
 
         return result
 
+    # 声明的类型为 IParam，调用  parse 进行转换
+    if issubclass(arg_spec.annotation, IParam):
+        result = arg_spec.annotation.parse(arg_value)
+        return result
+
     # 转换失败时，会抛出异常
     # noinspection PyBroadException
     try:
@@ -458,6 +465,7 @@ def _get_actual_args(request: HttpRequest, func, args_def: OrderedDict, config:
             continue
 
         val = _get_input_value(arg_spec, arg_name, arg_value, config)
+
         if isinstance(val, HttpResponse):
             return val
         actual_args[arg_name] = val
